diff a/src/hotspot/share/cds/cdsConfig.hpp b/src/hotspot/share/cds/cdsConfig.hpp
--- a/src/hotspot/share/cds/cdsConfig.hpp
+++ b/src/hotspot/share/cds/cdsConfig.hpp
@@ -1,7 +1,7 @@
 /*
- * Copyright (c) 2023, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2023, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 only, as
  * published by the Free Software Foundation.
@@ -34,10 +34,13 @@
   static bool _is_dumping_static_archive;
   static bool _is_dumping_dynamic_archive;
   static bool _dumping_full_module_graph_disabled;
   static bool _loading_full_module_graph_disabled;
 
+  static bool _module_patching_disables_cds;
+  static bool _java_base_module_patching_disables_cds;
+
   static char*  _default_archive_path;
   static char*  _static_archive_path;
   static char*  _dynamic_archive_path;
 #endif
 
@@ -50,11 +53,16 @@
 public:
   // Initialization and command-line checking
   static void initialize() NOT_CDS_RETURN;
   static void check_system_property(const char* key, const char* value) NOT_CDS_RETURN;
   static void check_unsupported_dumping_properties() NOT_CDS_RETURN;
-  static bool check_vm_args_consistency(bool patch_mod_javabase,  bool mode_flag_cmd_line) NOT_CDS_RETURN_(true);
+  static bool check_vm_args_consistency(bool mode_flag_cmd_line) NOT_CDS_RETURN_(true);
+
+  static bool module_patching_disables_cds() { return _module_patching_disables_cds; }
+  static void set_module_patching_disables_cds() { _module_patching_disables_cds = true; }
+  static bool java_base_module_patching_disables_cds() { return _java_base_module_patching_disables_cds; }
+  static void set_java_base_module_patching_disables_cds() { _java_base_module_patching_disables_cds = true; }
 
   // Basic CDS features
   static bool      is_dumping_archive()                      { return is_dumping_static_archive() || is_dumping_dynamic_archive(); }
   static bool      is_dumping_static_archive()               { return CDS_ONLY(_is_dumping_static_archive) NOT_CDS(false); }
   static void  enable_dumping_static_archive()               { CDS_ONLY(_is_dumping_static_archive = true); }
@@ -78,8 +86,9 @@
   static void disable_dumping_full_module_graph(const char* reason = nullptr) NOT_CDS_JAVA_HEAP_RETURN;
   static bool      is_dumping_full_module_graph()            NOT_CDS_JAVA_HEAP_RETURN_(false);
   static void disable_loading_full_module_graph(const char* reason = nullptr) NOT_CDS_JAVA_HEAP_RETURN;
   static bool      is_loading_full_module_graph()            NOT_CDS_JAVA_HEAP_RETURN_(false);
 
+  static bool      is_valhalla_preview();
 };
 
 #endif // SHARE_CDS_CDSCONFIG_HPP
